(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     87784,       2395]
NotebookOptionsPosition[     76056,       2212]
NotebookOutlinePosition[     76615,       2233]
CellTagsIndexPosition[     76572,       2230]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f9dbb5f8-90b5-4f6e-9155-03db53fa97d1"],

Cell["Chapter 5, Section 5.4", "Section",
 CellChangeTimes->{{3.811314850751381*^9, 3.811314854949946*^9}, {
   3.864540111774716*^9, 3.864540117550418*^9}, 
   3.864540174609716*^9},ExpressionUUID->"66fbd7cd-df79-44bb-b701-\
2c97ca5376ca"],

Cell["\<\
Here we derive the various algebraic results associated with spin-orbit \
resonance.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645402402657757`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4a71813e-2248-4c3f-a930-30a9c6885380"],

Cell[TextData[{
 "First we derive an expression for (",
 StyleBox["a/r",
  FontSlant->"Italic"],
 ")",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "3"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "ab11c030-e850-4941-b5ff-66a75f622671"],
 " as a series in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and cosines of multiples of the mean anomaly, ",
 StyleBox["M",
  FontSlant->"Italic"],
 ", using the results in Sect.2.5.  This gives us Eq.(5.61).  Note that we \
are expanding to the 4th power in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " because this will be needed later."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.8645405639520197`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8d5ad9d1-1810-46a6-b388-0e8942a7d74e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"aor3", " ", "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Collect", "[", 
     RowBox[{
      RowBox[{"Normal", "[", "\n", "       ", 
       RowBox[{"ExpandAll", "[", 
        RowBox[{
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"1", "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"Expand", "[", 
               RowBox[{"1", "+", 
                RowBox[{
                 RowBox[{"e", "^", "2"}], "/", "2"}], "-", 
                RowBox[{"2", "e", "*", 
                 RowBox[{"Series", "[", "\n", "       ", 
                  RowBox[{
                   RowBox[{"Sum", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"1", "/", 
                    RowBox[{"s", "^", "2"}]}], ")"}], 
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"BesselJ", "[", 
                    RowBox[{"s", ",", " ", 
                    RowBox[{"s", " ", "e"}]}], "]"}], ",", "e"}], "]"}], 
                    RowBox[{"Cos", "[", 
                    RowBox[{"s", " ", "M"}], "]"}]}], ",", 
                    RowBox[{"{", 
                    RowBox[{"s", ",", "1", ",", "6"}], "}"}]}], "]"}], ",", 
                   "\n", "       ", 
                   RowBox[{"{", 
                    RowBox[{"e", ",", "0", ",", "6"}], "}"}]}], "]"}]}]}], 
               "]"}], ")"}], "^", "3"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], ",", 
         RowBox[{"Trig", "->", "True"}]}], "]"}], "]"}], ",", "e"}], "]"}], "//",
     "Simplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.864537246050234*^9, 3.864537246052911*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"77e13c26-3bc3-4789-81ef-7cd947529d96"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["e", "2"]}], "2"], "+", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["e", "4"]}], "8"], "+", 
  RowBox[{"3", " ", "e", " ", 
   RowBox[{"Cos", "[", "M", "]"}]}], "+", 
  RowBox[{
   FractionBox["27", "8"], " ", 
   SuperscriptBox["e", "3"], " ", 
   RowBox[{"Cos", "[", "M", "]"}]}], "+", 
  RowBox[{
   FractionBox["9", "2"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["7", "2"], " ", 
   SuperscriptBox["e", "4"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["53", "8"], " ", 
   SuperscriptBox["e", "3"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"3", " ", "M"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["77", "8"], " ", 
   SuperscriptBox["e", "4"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"4", " ", "M"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.864537248415616*^9, 3.864538784064783*^9, 
  3.8645397157896833`*^9, 3.8645422057417517`*^9, 3.864542276352983*^9, 
  3.890929660656468*^9},
 CellLabel->"Out[1]=",ExpressionUUID->"abf0effe-0b45-4b08-b88c-cbf247c4b3d8"]
}, Open  ]],

Cell[TextData[{
 "Now we derive an expression for sin ",
 StyleBox["f",
  FontSlant->"Italic"],
 " as a series in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and sines of multiples of the mean anomaly, ",
 StyleBox["M",
  FontSlant->"Italic"],
 ", using the results in Sect.2.5.  This gives us Eq.(5.59).  Note that we \
are expanding to the 4th power in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " because this will be needed later."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.86454062057689*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7adba252-7a4b-4643-9a68-e15d96e06650"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sf", " ", "=", " ", 
  RowBox[{"Normal", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{"ExpandAll", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"Sqrt", "[", 
          RowBox[{"1", "-", 
           RowBox[{"e", "^", "2"}]}], "]"}], "*", "\n", "       ", 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "s"}], ")"}], 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"BesselJ", "[", 
               RowBox[{"s", ",", " ", 
                RowBox[{"s", " ", "e"}]}], "]"}], ",", "e"}], "]"}], 
            RowBox[{"Sin", "[", 
             RowBox[{"s", " ", "M"}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"s", ",", "1", ",", "6"}], "}"}]}], "]"}]}], ",", "\n", 
        "       ", 
        RowBox[{"{", 
         RowBox[{"e", ",", "0", ",", "6"}], "}"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.864537302481925*^9, 3.864537302485038*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"7cccf884-0680-4584-bea3-e48c56dbee4e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", "M", "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"7", " ", 
        RowBox[{"Sin", "[", "M", "]"}]}], "8"]}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["7", "6"]}], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"2", " ", "M"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["4", "3"], " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"4", " ", "M"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   FractionBox["1", "384"], " ", 
   SuperscriptBox["e", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"34", " ", 
      RowBox[{"Sin", "[", "M", "]"}]}], "-", 
     RowBox[{"621", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}], "+", 
     RowBox[{"625", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"5", " ", "M"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.864537303734744*^9, 3.8645387843108873`*^9, 
  3.864539716044054*^9, 3.86454220598547*^9, 3.864542276589703*^9, 
  3.890929661469225*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"da829839-8e40-462d-b5b1-eb01a19c944d"]
}, Open  ]],

Cell[TextData[{
 "Now we derive an expression for cos ",
 StyleBox["f",
  FontSlant->"Italic"],
 " as a series in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and cosines of multiples of the mean anomaly, ",
 StyleBox["M",
  FontSlant->"Italic"],
 ", using the results in Sect.2.5.  This gives us Eq.(5.60).  Note that we \
are expanding to the 4th power in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " because this will be needed later."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6b916a40-a589-44d9-af9e-04c993ab7d35"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cf", " ", "=", " ", 
  RowBox[{"Collect", "[", 
   RowBox[{
    RowBox[{"ExpandAll", "[", "\n", "       ", 
     RowBox[{"Series", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "e"}], "+", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"e", "^", "2"}]}], ")"}], "/", "e"}], " ", "*", "\n", 
           "       ", 
           RowBox[{"Sum", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"BesselJ", "[", 
               RowBox[{"s", ",", " ", 
                RowBox[{"s", " ", "e"}]}], "]"}], "*", 
              RowBox[{"Cos", "[", 
               RowBox[{"s", " ", "M"}], "]"}]}], ",", 
             RowBox[{"{", 
              RowBox[{"s", ",", "1", ",", "6"}], "}"}]}], "]"}]}], ",", "\n", 
          "       ", 
          RowBox[{"{", 
           RowBox[{"e", ",", "0", ",", "6"}], "}"}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], ",", "e"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.8645373237194567`*^9, 3.864537323722301*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"1a0cf2ff-e07b-4c75-82fc-fa2c51c86a6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Cos", "[", "M", "]"}], "+", 
  RowBox[{"e", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "M"}], "]"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"9", " ", 
        RowBox[{"Cos", "[", "M", "]"}]}], "8"]}], "+", 
     RowBox[{
      FractionBox["9", "8"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "3"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox["4", "3"]}], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", " ", "M"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["4", "3"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"4", " ", "M"}], "]"}]}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["e", "4"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"25", " ", 
       RowBox[{"Cos", "[", "M", "]"}]}], "192"], "-", 
     RowBox[{
      FractionBox["225", "128"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"3", " ", "M"}], "]"}]}], "+", 
     RowBox[{
      FractionBox["625", "384"], " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"5", " ", "M"}], "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.864537325948962*^9, 3.86453878435388*^9, 
  3.864539716087778*^9, 3.864542206027853*^9, 3.8645422766312513`*^9, 
  3.890929661530759*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"225ef911-4164-4dc4-8173-a2f35f45e3da"]
}, Open  ]],

Cell[TextData[{
 "We also need an expression for cos 2",
 StyleBox["f",
  FontSlant->"Italic"],
 " as a series in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and cosines of multiples of the mean anomaly, ",
 StyleBox["M",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d315b6c0-9794-4d66-8bfb-40bd5102c40b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"c2f", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Collect", "[", "\n", "        ", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"cf", "*", "cf"}], "-", 
           RowBox[{"sf", "*", "sf"}]}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], ",", 
       "\n", "        ", 
       RowBox[{"Trig", "->", "True"}]}], "]"}], ",", "e"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.864539159577866*^9, 3.864539159580557*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"b09cebbb-67db-4438-bcaa-2809f8cf524e"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "48"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"8", " ", "e", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "12"}], "+", 
       RowBox[{"11", " ", 
        SuperscriptBox["e", "2"]}]}], ")"}], " ", 
     RowBox[{"Cos", "[", "M", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"48", "-", 
       RowBox[{"192", " ", 
        SuperscriptBox["e", "2"]}], "+", 
       RowBox[{"167", " ", 
        SuperscriptBox["e", "4"]}]}], ")"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", " ", "M"}], "]"}]}], "+", 
    RowBox[{"e", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"96", "-", 
          RowBox[{"324", " ", 
           SuperscriptBox["e", "2"]}]}], ")"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"3", " ", "M"}], "]"}]}], "+", 
       RowBox[{"e", " ", 
        RowBox[{"(", 
         RowBox[{"36", "+", 
          RowBox[{"6", " ", 
           SuperscriptBox["e", "2"]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"156", "-", 
             RowBox[{"518", " ", 
              SuperscriptBox["e", "2"]}]}], ")"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"4", " ", "M"}], "]"}]}], "+", 
          RowBox[{"236", " ", "e", " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"5", " ", "M"}], "]"}]}], "+", 
          RowBox[{"345", " ", 
           SuperscriptBox["e", "2"], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"6", " ", "M"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{3.8645391606224937`*^9, 3.8645397162833767`*^9, 
  3.864542206214912*^9, 3.864542276815896*^9, 3.890929661734613*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"71ab3d4b-a409-482f-9ad3-1066f28604f5"]
}, Open  ]],

Cell[TextData[{
 "We also need an expression for sin 2",
 StyleBox["f",
  FontSlant->"Italic"],
 " as a series in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and sines of multiples of the mean anomaly, ",
 StyleBox["M",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540789942155*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ca0afd13-75e0-427b-afd6-a4e873a9cca3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"s2f", " ", "=", " ", 
  RowBox[{"Simplify", "[", 
   RowBox[{"Collect", "[", "\n", "        ", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"2", "*", "sf", "*", "cf"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], ",", 
       "\n", "        ", 
       RowBox[{"Trig", "->", "True"}]}], "]"}], ",", "e"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.864539173451227*^9, 3.86453917345433*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"4861e4cc-edfd-4d6c-a8ab-6b683743c137"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "24"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "24"}], "+", 
       RowBox[{"18", " ", 
        SuperscriptBox["e", "2"]}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["e", "4"]}]}], ")"}], " ", 
     RowBox[{"Cos", "[", "M", "]"}]}], "+", 
    RowBox[{"e", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"96", "-", 
          RowBox[{"88", " ", 
           SuperscriptBox["e", "2"]}]}], ")"}], " ", 
        RowBox[{"Cos", "[", 
         RowBox[{"2", " ", "M"}], "]"}]}], "+", 
       RowBox[{"e", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"156", "-", 
             RowBox[{"173", " ", 
              SuperscriptBox["e", "2"]}]}], ")"}], " ", 
           RowBox[{"Cos", "[", 
            RowBox[{"3", " ", "M"}], "]"}]}], "+", 
          RowBox[{"e", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             RowBox[{"236", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"4", " ", "M"}], "]"}]}], "+", 
             RowBox[{"345", " ", "e", " ", 
              RowBox[{"Cos", "[", 
               RowBox[{"5", " ", "M"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}]}]}], ")"}], " ", 
  RowBox[{"Sin", "[", "M", "]"}]}]], "Output",
 CellChangeTimes->{3.864539175126177*^9, 3.8645397164372473`*^9, 
  3.8645422064159193`*^9, 3.86454227695991*^9, 3.890929661942832*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"b582de05-89a9-45bf-9f45-3a86e94f601e"]
}, Open  ]],

Cell[TextData[{
 "We now use these series to derive expressions for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "e1939e8f-f4fa-459c-a462-4946b8954c7e"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "6337841e-3f6b-47a7-9174-cc1a40daeb0a"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "8d7225eb-82e2-4143-8ca3-9b7c66ea19d8"],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "4"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "00843ce4-54f5-456f-9feb-75f7c0778808"],
 " using the definitions in Eq.(5.64)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864540953849517*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2a9680b1-c62f-447e-adac-6233c1e52e7d"],

Cell[TextData[{
 "Calculate an expression for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "9a5745f9-e0fc-438a-b9fc-6c8eeeca9a81"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541197270672*^9, 3.864541210980609*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3b436687-41d9-4ea4-a622-60fd9f550ccc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S1", " ", "=", " ", 
   RowBox[{"Collect", "[", "\n", "       ", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"aor3", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", "*", "p", "*", "M"}], "]"}], "*", "c2f"}], ",", "\n",
           "       ", 
          RowBox[{"{", 
           RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"Trig", "->", "True"}]}], "]"}], ",", " ", "e"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.86453918881136*^9, 3.8645391888140697`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"563dff97-1f75-4b4f-9652-f0d6592adf7b"],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "0"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "2f4c33d9-4ea2-4fcc-ac5b-33fdf2787134"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "86ec7f6d-2471-45d4-bb79-57469f2cb358"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"0cc0b86c-0b91-439a-bade-b643345a5cf6"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S1, e, 0]]", "Input",
 CellChangeTimes->{{3.8645374138900623`*^9, 3.864537414309577*^9}, {
  3.864537448359515*^9, 3.864537490360362*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"493c1854-3bef-4180-abe8-d7f7c4d4188b"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "-", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}], "+", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "+", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.864537107889377*^9, 3.8645374149923983`*^9, {3.8645374450098257`*^9, 
   3.864537491329273*^9}, 3.864537576424015*^9, 3.864538784743248*^9, 
   3.864539716472392*^9, 3.864542206450241*^9, 3.8645422769944267`*^9, 
   3.890929662023138*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",ExpressionUUID->"777ca600-195f-456a-82d8-9bfad1f04161"]
}, Open  ]],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "0d5f973b-95b0-4a6d-92ad-45652e9f0c79"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "c01401fd-cbc7-4d72-a1f1-860c0a0af7da"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541048978705*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fbca6586-3ed5-459a-b50d-c2b31dd2a872"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S1, e, 1]]", "Input",
 CellChangeTimes->{{3.8645375018054533`*^9, 3.864537512379524*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"f0252a9a-f232-46fe-b998-90847b6a0dab"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cos", "[", 
      RowBox[{"M", "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "-", 
    RowBox[{"Cos", "[", 
     RowBox[{"M", "+", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864537107897911*^9, 3.864537513499875*^9, 
  3.864537578899762*^9, 3.8645387847570467`*^9, 3.864539716487789*^9, 
  3.864542206464447*^9, 3.864542277010294*^9, 3.8909296620827627`*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",ExpressionUUID->"122f1eb1-5ecc-4940-bb58-7967d14e83ec"]
}, Open  ]],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "298635f5-cf80-4a8e-896f-a18fbbde57bc"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "090b682c-2d60-4a50-8664-d033185ceffd"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.86454105944973*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"17d45542-73e8-4cef-beae-a9352ac66d6a"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S1, e, 2]]", "Input",
 CellChangeTimes->{{3.8645375294645863`*^9, 3.864537539934895*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"85d4b5e5-43a5-47ac-8c4a-29fe9e6266d3"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "5"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"17", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "-", 
    RowBox[{"5", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"17", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8645371079049053`*^9, 3.864537540920599*^9, 
  3.864537581315063*^9, 3.8645387847667427`*^9, 3.864539716496418*^9, 
  3.8645422064714622`*^9, 3.8645422770199957`*^9, 3.890929662101317*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",ExpressionUUID->"1a9a362e-7f75-4a1c-94e4-b45cade49362"]
}, Open  ]],

Cell[TextData[{
 "Calculate an expression for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "5d56b5ad-ec67-4515-b48b-93f2c441df88"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541197270672*^9, 3.864541223490769*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c799e14e-0637-4151-a9a3-85c400b1b6fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S2", " ", "=", " ", 
   RowBox[{"Collect", "[", "\n", "       ", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"aor3", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", "*", "p", "*", "M"}], "]"}], "*", "s2f"}], ",", "\n",
           "       ", 
          RowBox[{"{", 
           RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"Trig", "->", "True"}]}], "]"}], ",", " ", "e"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.8645392130195627`*^9, 3.8645392130247097`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"99e61c54-bdc4-4b33-8b82-8e0d7d880b5f"],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "0"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "a8f6aef0-bf1f-4d76-a171-75b29cc19824"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "5c581987-b0d9-4994-9aab-1ff9193219be"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4e573959-b360-49bf-ae4f-b116b07087b9"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S2, e, 0]]", "Input",
 CellChangeTimes->{{3.8645376055754232`*^9, 3.864537627414722*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[11]:=",ExpressionUUID->"69c0ffeb-16c5-4012-8473-3e0a99c296e2"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "-", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}], "-", 
    RowBox[{"Cos", "[", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "+", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.864537107934668*^9, {3.864537607446259*^9, 3.8645376291504908`*^9}, 
   3.864538784793973*^9, 3.864539716524811*^9, 3.864542206499086*^9, 
   3.864542277046775*^9, 3.890929662165448*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",ExpressionUUID->"813dfba7-9933-430f-a971-83751d9a9883"]
}, Open  ]],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "5bb6f8e5-3e91-43f3-bd82-d530549d6972"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "3395dc07-9a4c-491f-991f-2267aedf0191"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541142265649*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"316bacd5-131e-49ec-840f-efce06887da8"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S2, e, 1]]", "Input",
 CellChangeTimes->{{3.8645376413813753`*^9, 3.864537648264805*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[12]:=",ExpressionUUID->"0443ad6d-08ba-43f4-907c-93d05659c041"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Cos", "[", 
      RowBox[{"M", "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"Cos", "[", 
     RowBox[{"M", "+", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}], "-", 
    RowBox[{"7", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8645371079429083`*^9, 3.864537649053247*^9, 
  3.864538784807913*^9, 3.864539716538692*^9, 3.86454220651261*^9, 
  3.8645422770630693`*^9, 3.890929662219523*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",ExpressionUUID->"9fe29c66-ca64-40b1-9ffa-b05d3be39dff"]
}, Open  ]],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "5472ea0e-698a-4f91-bfaa-040f7db3e1d6"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "db1af832-a6cf-44de-9e7f-c1b58bb33ed7"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541154370502*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ad772f01-1bea-48f3-8dec-84b13a0d0466"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S2, e, 2]]", "Input",
 CellChangeTimes->{{3.8645376607457323`*^9, 3.8645376662044563`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[13]:=",ExpressionUUID->"7dcfdbe9-6f07-4694-81a6-856af4ab4624"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "5"}], " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"17", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "-", 
    RowBox[{"17", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864537107947657*^9, 3.864537667127879*^9, 
  3.8645387848162737`*^9, 3.864539716548451*^9, 3.8645422065194883`*^9, 
  3.864542277071628*^9, 3.890929662234397*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",ExpressionUUID->"651f75f9-c424-4ff3-aea9-e4d0f3af5698"]
}, Open  ]],

Cell[TextData[{
 "Calculate an expression for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "b40758ad-a378-4acb-83c5-6e412eaa8456"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541197270672*^9, 3.864541232850255*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"004e3db8-9908-4586-8da5-a602c0b7d852"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S3", " ", "=", " ", 
   RowBox[{"Collect", "[", "\n", "       ", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"aor3", "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"2", "*", "p", "*", "M"}], "]"}], "*", "c2f"}], ",", "\n",
           "       ", 
          RowBox[{"{", 
           RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"Trig", "->", "True"}]}], "]"}], ",", " ", "e"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.864539227270146*^9, 3.864539227273034*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"cd0892b7-1450-4923-bdc1-e3554c6d9dd6"],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "0"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "a1873d4b-552a-453d-a41f-552d201b2eb2"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "6f259880-cbb6-4798-9215-c265b16fa72e"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541307235795*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"924c190a-2302-43eb-bf50-2b78c56a6dee"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S3, e, 0]]", "Input",
 CellChangeTimes->{{3.864537696226074*^9, 3.864537699224972*^9}, {
  3.86453773953065*^9, 3.864537740085136*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[15]:=",ExpressionUUID->"44d7b32b-c441-471f-b669-ea057a10514d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "+", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864537107968409*^9, 3.864537700195175*^9, 
  3.864538784837173*^9, 3.8645397165695343`*^9, 3.864542206538876*^9, 
  3.864542277091387*^9, 3.890929662298458*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",ExpressionUUID->"4726ef6c-3404-4037-9508-2154f87a7ad4"]
}, Open  ]],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "9c1e960d-dbad-4533-b38c-408a1ce17592"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "ba7490a0-dc0f-4340-a89d-8502940c7039"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541320210722*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cfb5c831-952b-42b7-8967-a0342e9d1534"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S3, e, 1]]", "Input",
 CellChangeTimes->{{3.864537717796872*^9, 3.86453774304016*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[16]:=",ExpressionUUID->"b59b8936-16fe-4ffc-b7c8-b6a023000308"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"M", "-", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}], "-", 
    RowBox[{"7", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "-", 
    RowBox[{"Sin", "[", 
     RowBox[{"M", "+", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864537107977145*^9, 3.864537721074602*^9, 
  3.864538784850336*^9, 3.864539716584214*^9, 3.8645422065532103`*^9, 
  3.86454227709772*^9, 3.890929662351925*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[16]=",ExpressionUUID->"46ed4b13-9f2e-466b-a848-760ffc020dd7"]
}, Open  ]],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "9689eab7-f56d-4edc-a19a-f40d35a62ce8"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "3"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "74215d58-2204-417f-9894-2cc2659e2b64"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541329360835*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a81f424e-2cd6-410e-801b-22af70969d5c"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S3, e, 2]]", "Input",
 CellChangeTimes->{{3.864537726451867*^9, 3.8645377471053543`*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[17]:=",ExpressionUUID->"d510654b-d5be-4d44-a1ae-295ca4fc1b62"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"5", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "-", 
    RowBox[{"17", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "-", 
    RowBox[{"5", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"17", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.864537107982003*^9, {3.864537730032694*^9, 3.864537747957638*^9}, 
   3.864538784857348*^9, 3.864539716591557*^9, 3.864542206560151*^9, 
   3.864542277113534*^9, 3.8909296623684483`*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",ExpressionUUID->"6275a92b-534e-4ada-a9a8-d9c866fbefa3"]
}, Open  ]],

Cell[TextData[{
 "Calculate an expression for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "4"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "be3d353f-5cdd-4676-81d2-83553050d333"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541197270672*^9, 3.8645412535051117`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ee5259ee-1423-43d8-b1be-821b589c185b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"S4", " ", "=", " ", 
   RowBox[{"Collect", "[", "\n", "       ", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{
       RowBox[{"Normal", "[", 
        RowBox[{"Series", "[", 
         RowBox[{
          RowBox[{"aor3", "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"2", "*", "p", "*", "M"}], "]"}], "*", "s2f"}], ",", "\n",
           "       ", 
          RowBox[{"{", 
           RowBox[{"e", ",", "0", ",", "4"}], "}"}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"Trig", "->", "True"}]}], "]"}], ",", " ", "e"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.864539242540811*^9, 3.864539242543565*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"dd445204-39ad-4670-8626-7793d66692a8"],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "0"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "bb6b4610-579e-4801-a0e6-06b00d4c7d4f"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "4"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "bf43d071-72ed-4453-baa0-56b1abda4cec"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f49c0f65-e43d-434f-bde7-f4d42ed63c78"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S4, e, 0]]", "Input",
 CellChangeTimes->{{3.864537762290205*^9, 3.864537768840975*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[19]:=",ExpressionUUID->"258d4f7d-ffb0-4148-8501-bf79a67e143d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "-", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}], "+", 
    RowBox[{"Sin", "[", 
     RowBox[{
      RowBox[{"2", " ", "M"}], "+", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864537769629467*^9, 3.864538784877552*^9, 
  3.8645397166133623`*^9, 3.864542206582045*^9, 3.864542277133809*^9, 
  3.890929662432672*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"331abae0-d8b2-4f08-9b9b-bc880dcc03b1"]
}, Open  ]],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "1"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "8a6a9bd6-0fdd-43e2-84cd-cf6b6193686e"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "4"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "a0f70df0-c049-4ee7-a358-7e171703573b"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.864541396267816*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b637f3f4-00e5-4950-b322-1c372142414b"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S4, e, 1]]", "Input",
 CellChangeTimes->{{3.864537762290205*^9, 3.864537768840975*^9}, {
  3.864541399192272*^9, 3.864541399597171*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[20]:=",ExpressionUUID->"e70467fa-4c8b-4586-bcce-713880b80faf"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "-", 
    RowBox[{"Sin", "[", 
     RowBox[{"M", "+", 
      RowBox[{"2", " ", "M", " ", "p"}]}], "]"}], "+", 
    RowBox[{"7", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864541400516857*^9, 3.864542206596966*^9, 
  3.864542277149599*^9, 3.8909296624872713`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"8e014a64-a624-4d72-8ddb-637ab2aea0ba"]
}, Open  ]],

Cell[TextData[{
 "Calculate the coefficient of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "046b97da-8e04-43b8-b30c-13ae63bd7f33"],
 " in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["S", "4"], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "7f983d94-9ad1-43a6-99fe-b60455dd4b61"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2f8c2afc-cf40-4060-ba50-e636f4bd6f95"],

Cell[CellGroupData[{

Cell["TrigReduce[Coefficient[S4, e, 2]]", "Input",
 CellChangeTimes->{{3.864537762290205*^9, 3.864537768840975*^9}, {
  3.864541399192272*^9, 3.864541399597171*^9}, {3.864541431475458*^9, 
  3.864541432556099*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[21]:=",ExpressionUUID->"9bd4406f-229d-47d4-bf27-75e0b4b15348"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "4"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "5"}], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"17", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "-", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "-", 
    RowBox[{"5", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}], "+", 
    RowBox[{"17", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "+", 
       RowBox[{"2", " ", "M", " ", "p"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864541433822703*^9, 3.864542206605872*^9, 
  3.8645422771581497`*^9, 3.890929662501478*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"eb42c15f-f88d-48ab-983f-6676d2e399cd"]
}, Open  ]],

Cell[TextData[{
 "Here we follow the example given in the book for the synchronous case (when \
",
 StyleBox["p",
  FontSlant->"Italic"],
 " = 1)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"865b81b9-1d36-4088-907c-cc447ed20a71"],

Cell[BoxData[
 RowBox[{
  RowBox[{"expr", " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"S1", "+", "S2"}], ")"}], "*", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", "*", "\[Gamma]"}], "]"}]}], " ", "+", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"S3", "-", "S4"}], ")"}], "*", 
     RowBox[{"Cos", "[", 
      RowBox[{"2", "*", "\[Gamma]"}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.864539276485009*^9, 3.864539276487742*^9}},
 CellLabel->"In[22]:=",ExpressionUUID->"4020b2d4-f652-4f27-942b-7f9a9ec89fed"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr1", " ", "=", " ", 
  RowBox[{"TrigReduce", "[", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{"Expand", "[", 
      RowBox[{"(", 
       RowBox[{"expr", " ", "/.", " ", 
        RowBox[{"p", "->", "1"}]}], ")"}], "]"}], ",", " ", "e"}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.86453929526572*^9, 3.8645392952686377`*^9}},
 CellLabel->"In[23]:=",ExpressionUUID->"54612606-9590-4977-aec5-5faf0ec74a3c"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "48"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "168"}], " ", "e", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "-", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "+", 
    RowBox[{"369", " ", 
     SuperscriptBox["e", "3"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "-", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "-", 
    RowBox[{"408", " ", 
     SuperscriptBox["e", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "+", 
    RowBox[{"920", " ", 
     SuperscriptBox["e", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "-", 
    RowBox[{"845", " ", 
     SuperscriptBox["e", "3"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "-", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "-", 
    RowBox[{"1599", " ", 
     SuperscriptBox["e", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "-", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "+", 
    RowBox[{"48", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "-", 
    RowBox[{"120", " ", 
     SuperscriptBox["e", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "+", 
    RowBox[{"39", " ", 
     SuperscriptBox["e", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "-", 
    RowBox[{"24", " ", "e", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "+", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["e", "3"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "+", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["e", "3"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"3", " ", "M"}], "+", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "+", 
    RowBox[{"2", " ", 
     SuperscriptBox["e", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"4", " ", "M"}], "+", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8645392967308187`*^9, 3.8645397166405077`*^9, 
  3.8645422066350822`*^9, 3.864542277186734*^9, 3.890929662567154*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"b429268a-caa7-453a-bf7d-cabee1c54a9f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"expr12", " ", "=", " ", 
  RowBox[{"expr1", " ", "/.", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"e", "^", "3"}], "->", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"e", "^", "4"}], "->", "0"}]}], "}"}]}]}]], "Input",
 CellChangeTimes->{{3.864539313310316*^9, 3.864539313312928*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"9840c230-365c-49c7-ade0-5ba44668859d"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "48"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "168"}], " ", "e", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "-", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "-", 
    RowBox[{"408", " ", 
     SuperscriptBox["e", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}], "+", 
    RowBox[{"48", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "-", 
    RowBox[{"120", " ", 
     SuperscriptBox["e", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "-", 
    RowBox[{"24", " ", "e", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"M", "+", 
       RowBox[{"2", " ", "\[Gamma]"}]}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864539314527349*^9, 3.864539716649722*^9, 
  3.864542206642976*^9, 3.864542277194808*^9, 3.8909296626220427`*^9},
 CellLabel->"Out[24]=",ExpressionUUID->"4447c17f-6465-4678-acb2-601d0f4fe88a"]
}, Open  ]],

Cell["This gives us the expression shown in Eq.(5.72).", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.86454161387827*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"02a43df3-3e84-4bec-ad2d-380f6b3e10bc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Expand", "[", 
  RowBox[{
   RowBox[{"Integrate", "[", 
    RowBox[{"expr12", ",", " ", 
     RowBox[{"{", 
      RowBox[{"M", ",", "0", ",", 
       RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
   RowBox[{"(", 
    RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.86453934317498*^9, 3.864539343179777*^9}},
 CellLabel->"In[25]:=",ExpressionUUID->"8f75e1e1-f7ae-4d64-9bd8-2cdac4bd1854"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "\[Gamma]"}], "]"}], "-", 
  RowBox[{
   FractionBox["5", "2"], " ", 
   SuperscriptBox["e", "2"], " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.864539345089752*^9, 3.864539716955461*^9, 
  3.8645422068843307`*^9, 3.864542277451928*^9, 3.890929662926713*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"d7ccabb7-fb4b-405d-b49a-64a2ac432922"]
}, Open  ]],

Cell[TextData[{
 "We now derive the expressions for ",
 StyleBox["H",
  FontSlant->"Italic"],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ",",
 StyleBox["e",
  FontSlant->"Italic"],
 ") shown in Eqs.(5.74-5.82).  Note that here we are using 4th order \
expansions derived above."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541685683427*^9}, {3.864542226573044*^9, 3.864542259946509*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"99fd2e23-f6a1-4169-a887-2ff12e3ae167"],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = -1 case, Eq.(5.74)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"048b4c54-176d-42bc-aa5d-ca2e1d3f209e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t1", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", " ", 
       RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8645393586581507`*^9, 3.864539358660975*^9}},
 CellLabel->"In[26]:=",ExpressionUUID->"6c32f9ab-8549-4ec9-8047-f4f891806e4c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t1", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8645393807499323`*^9, 3.86453938075259*^9}},
 CellLabel->"In[27]:=",ExpressionUUID->"686839ee-e1ab-4e7a-8bd0-9f8d79e58344"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "24"], " ", 
  SuperscriptBox["e", "4"], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]], "Output",
 CellChangeTimes->{3.864539382140891*^9, 3.864539717488941*^9, 
  3.8645422073865347`*^9, 3.8645422780204153`*^9, 3.8909296637711763`*^9},
 CellLabel->"Out[27]=",ExpressionUUID->"eb1ba5c4-62d4-4f04-9f1a-3f16e009f353"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = -1/2 case, Eq.(5.75)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}, {3.8645418858448133`*^9, 3.8645418913644648`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b825c3eb-0c6c-48be-8196-f8f61eba9b84"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t2", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", " ", 
       RowBox[{
        RowBox[{"-", "1"}], "/", "2"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.864539399875102*^9, 3.864539399880554*^9}},
 CellLabel->"In[28]:=",ExpressionUUID->"614cb1d3-ac65-4175-a92c-32eaa730f140"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t2", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.864539411621661*^9, 3.864539411624427*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"83c3789b-cf43-4cb7-8cd6-311f7104a258"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "48"], " ", 
  SuperscriptBox["e", "3"], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]], "Output",
 CellChangeTimes->{3.8645394137005672`*^9, 3.864539717926935*^9, 
  3.864542207825856*^9, 3.864542278466917*^9, 3.890929664316907*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"00c885e3-c899-4839-bc46-be82426731f8"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = 0 case, Eq.(5.76)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}, {3.864541899375188*^9, 3.864541903905216*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"74505a0d-aa10-4d3e-86ab-a1bd071d3e1f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t0", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", "0"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.864538227357953*^9, 3.864538250176162*^9}, {
  3.864538399983159*^9, 3.864538400220405*^9}},
 CellLabel->"In[30]:=",ExpressionUUID->"d8de1239-b84a-48a6-9fc2-8cae19f1e19c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t0", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.864538263384438*^9, 3.8645382687599077`*^9}, {
  3.8645384038522387`*^9, 3.864538406940895*^9}},
 CellLabel->"In[31]:=",ExpressionUUID->"f086fc16-951b-4481-94ad-dd930dac0188"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.8645382701694517`*^9, 3.86453841268402*^9, 
  3.864538784985302*^9, 3.864539429597867*^9, 3.864539718288229*^9, 
  3.864542208183325*^9, 3.864542278843958*^9, 3.890929664868597*^9},
 CellLabel->"Out[31]=",ExpressionUUID->"2b58f78b-4cab-458b-9061-151c984660b4"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = +1/2 case, Eq.(5.77)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}, {3.864541912724522*^9, 3.8645419189045877`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"479f1934-8c58-4aba-a5ad-bd197c0f7e4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t3", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", " ", 
       RowBox[{"1", "/", "2"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.864539437827467*^9, 3.864539437830351*^9}},
 CellLabel->"In[32]:=",ExpressionUUID->"78b6ad9c-e09e-4638-97a7-1de8973ee9ac"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t3", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8645394488208847`*^9, 3.864539448823635*^9}},
 CellLabel->"In[33]:=",ExpressionUUID->"19c43925-5c86-424a-bfcc-dc3e7ab7b855"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "16"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "8"}], " ", "e", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "+", 
    RowBox[{
     SuperscriptBox["e", "3"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.86453944989815*^9, 3.864539718824625*^9, 
  3.8645422087260303`*^9, 3.8645422793680058`*^9, 3.890929665493649*^9},
 CellLabel->"Out[33]=",ExpressionUUID->"09556cb3-c3e6-4859-9543-b482fd562670"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = +1 (synchronous) case, Eq.(5.78)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}, {3.864541981095482*^9, 3.864541997626264*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"cfc13326-2bcf-4a1a-b9a1-e9b363a070ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t4", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", " ", "1"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.864539469222884*^9, 3.864539469225594*^9}},
 CellLabel->"In[34]:=",ExpressionUUID->"2893ca06-baaa-431a-9b0b-2f60d6cd36de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t4", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.864539480907112*^9, 3.8645394809098043`*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"b3b96bb9-7565-486e-9869-5370d6d02021"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "16"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"16", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "-", 
    RowBox[{"40", " ", 
     SuperscriptBox["e", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "+", 
    RowBox[{"13", " ", 
     SuperscriptBox["e", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864539481950536*^9, 3.86453971923218*^9, 
  3.864542209135992*^9, 3.864542279772781*^9, 3.8909296660594873`*^9},
 CellLabel->"Out[35]=",ExpressionUUID->"afa3d128-07ab-40ca-8d57-b31ae65be6cc"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = +3/2 case, Eq.(5.79)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}, {3.864541912724522*^9, 3.8645419189045877`*^9}, {
  3.8645420154014187`*^9, 3.864542019570867*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"4b3d9898-e689-4c8c-b25c-97166dfbcd92"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t5", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", " ", 
       RowBox[{"3", "/", "2"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.864539496912628*^9, 3.8645394969155407`*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"b2c1ce38-e8f6-4414-8415-a97860a29764"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t5", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8645395117002153`*^9, 3.8645395117029657`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"b152a936-c916-441b-832a-89f52d8d7999"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "16"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"56", " ", "e", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "-", 
    RowBox[{"123", " ", 
     SuperscriptBox["e", "3"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864539512905789*^9, 3.864539719741151*^9, 
  3.864542209646669*^9, 3.864542280284256*^9, 3.890929666675954*^9},
 CellLabel->"Out[37]=",ExpressionUUID->"631e5003-1060-4c8e-9069-3a14a0f211d5"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = +2 case, Eq.(5.80)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}, {3.864541912724522*^9, 3.8645419189045877`*^9}, {
  3.864542030731926*^9, 3.864542036956484*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"5dac8e94-09a1-4bf3-b621-69aa15b92d38"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t6", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", " ", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8645395258619432`*^9, 3.864539525867186*^9}},
 CellLabel->"In[38]:=",ExpressionUUID->"1b7a2c92-21fe-4a99-8aba-4a5f0cd6616e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t6", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.864539537941885*^9, 3.86453953794468*^9}},
 CellLabel->"In[39]:=",ExpressionUUID->"4bba5e2f-65bf-4870-b02f-c5569f2c6d9b"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "6"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"51", " ", 
     SuperscriptBox["e", "2"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}], "-", 
    RowBox[{"115", " ", 
     SuperscriptBox["e", "4"], " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.864539539233004*^9, 3.864539720183436*^9, 
  3.864542210088336*^9, 3.86454228071354*^9, 3.890929667285892*^9},
 CellLabel->"Out[39]=",ExpressionUUID->"94289231-2160-4ffa-87a0-0b9372693e80"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = +5/2 case, Eq.(5.81)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}, {3.864541912724522*^9, 3.8645419189045877`*^9}, {
  3.864542047545823*^9, 3.864542057147077*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d759bbb0-62b0-47cb-b148-44417fde99b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t7", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", " ", 
       RowBox[{"5", "/", "2"}]}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8645395549045963`*^9, 3.86453955490738*^9}},
 CellLabel->"In[40]:=",ExpressionUUID->"5c591503-e2cb-4da0-9ece-7a78ebf766e3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t7", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.864539567598206*^9, 3.8645395676010523`*^9}},
 CellLabel->"In[41]:=",ExpressionUUID->"8166ce6e-5f55-4aa5-80ab-6203c597d1a7"],

Cell[BoxData[
 RowBox[{
  FractionBox["845", "48"], " ", 
  SuperscriptBox["e", "3"], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]], "Output",
 CellChangeTimes->{3.8645395689034147`*^9, 3.864539720801792*^9, 
  3.864542210708126*^9, 3.864542281325406*^9, 3.890929668001338*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"dcef876d-ea98-4f39-81c5-6596a2b53625"]
}, Open  ]],

Cell[TextData[{
 "The ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = +3 case, Eq.(5.82)."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.864540205644465*^9, 3.8645403806355343`*^9}, {
  3.864540501475885*^9, 3.864540671831853*^9}, {3.8645407203125353`*^9, 
  3.864540769137959*^9}, {3.8645408098787003`*^9, 3.864541031205174*^9}, {
  3.864541129635717*^9, 3.864541130820623*^9}, {3.864541306770722*^9, 
  3.864541352896687*^9}, {3.8645413958625793`*^9, 3.8645414180798388`*^9}, {
  3.864541498182014*^9, 3.8645415379920053`*^9}, {3.864541586562767*^9, 
  3.864541720679084*^9}, {3.864541912724522*^9, 3.8645419189045877`*^9}, {
  3.864542065261952*^9, 3.864542075310709*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8d00d71d-98ae-4094-aa3e-03816d77a5c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t8", " ", "=", " ", 
   RowBox[{"Expand", "[", 
    RowBox[{"expr", " ", "/.", " ", 
     RowBox[{"{", 
      RowBox[{"p", " ", "->", " ", "3"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.864539582086678*^9, 3.8645395820895033`*^9}},
 CellLabel->"In[42]:=",ExpressionUUID->"448ace26-d251-4a31-8d1d-922606f40956"],

Cell[BoxData[
 RowBox[{"TrigReduce", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{"Integrate", "[", 
     RowBox[{"t8", ",", " ", 
      RowBox[{"{", 
       RowBox[{"M", ",", "0", ",", 
        RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"2", "\[Pi]"}], ")"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.8645395925121202`*^9, 3.864539592514948*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"7e62932f-ac3f-4bc1-943e-15ec40626233"],

Cell[BoxData[
 RowBox[{
  FractionBox["533", "16"], " ", 
  SuperscriptBox["e", "4"], " ", 
  RowBox[{"Sin", "[", 
   RowBox[{"2", " ", "\[Gamma]"}], "]"}]}]], "Output",
 CellChangeTimes->{3.864539640201151*^9, 3.864539721344969*^9, 
  3.864542211256172*^9, 3.864542281866004*^9, 3.89092966872849*^9},
 CellLabel->"Out[43]=",ExpressionUUID->"530643bd-b3a3-4fc6-8023-bdcd7b310ca4"]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{997, 650},
WindowMargins->{{81, Automatic}, {Automatic, 30}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"f19efb6b-8df5-46d6-a94a-92bbaf780056"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"f9dbb5f8-90b5-4f6e-9155-03db53fa97d1"],
Cell[948, 30, 240, 4, 67, "Section",ExpressionUUID->"66fbd7cd-df79-44bb-b701-2c97ca5376ca"],
Cell[1191, 36, 286, 7, 49, "Text",ExpressionUUID->"4a71813e-2248-4c3f-a930-30a9c6885380"],
Cell[1480, 45, 849, 26, 76, "Text",ExpressionUUID->"8d5ad9d1-1810-46a6-b388-0e8942a7d74e"],
Cell[CellGroupData[{
Cell[2354, 75, 1855, 45, 94, "Input",ExpressionUUID->"77e13c26-3bc3-4789-81ef-7cd947529d96"],
Cell[4212, 122, 1225, 37, 53, "Output",ExpressionUUID->"abf0effe-0b45-4b08-b88c-cbf247c4b3d8"]
}, Open  ]],
Cell[5452, 162, 674, 20, 76, "Text",ExpressionUUID->"7adba252-7a4b-4643-9a68-e15d96e06650"],
Cell[CellGroupData[{
Cell[6151, 186, 1227, 32, 73, "Input",ExpressionUUID->"7cccf884-0680-4584-bea3-e48c56dbee4e"],
Cell[7381, 220, 1474, 47, 90, "Output",ExpressionUUID->"da829839-8e40-462d-b5b1-eb01a19c944d"]
}, Open  ]],
Cell[8870, 270, 677, 20, 76, "Text",ExpressionUUID->"6b916a40-a589-44d9-af9e-04c993ab7d35"],
Cell[CellGroupData[{
Cell[9572, 294, 1271, 34, 94, "Input",ExpressionUUID->"1a0cf2ff-e07b-4c75-82fc-fa2c51c86a6b"],
Cell[10846, 330, 1596, 52, 89, "Output",ExpressionUUID->"225ef911-4164-4dc4-8173-a2f35f45e3da"]
}, Open  ]],
Cell[12457, 385, 541, 17, 53, "Text",ExpressionUUID->"d315b6c0-9794-4d66-8bfb-40bd5102c40b"],
Cell[CellGroupData[{
Cell[13023, 406, 730, 19, 73, "Input",ExpressionUUID->"b09cebbb-67db-4438-bcaa-2809f8cf524e"],
Cell[13756, 427, 1816, 53, 75, "Output",ExpressionUUID->"71ab3d4b-a409-482f-9ad3-1066f28604f5"]
}, Open  ]],
Cell[15587, 483, 539, 17, 53, "Text",ExpressionUUID->"ca0afd13-75e0-427b-afd6-a4e873a9cca3"],
Cell[CellGroupData[{
Cell[16151, 504, 673, 17, 73, "Input",ExpressionUUID->"4861e4cc-edfd-4d6c-a8ab-6b683743c137"],
Cell[16827, 523, 1672, 49, 95, "Output",ExpressionUUID->"b582de05-89a9-45bf-9f45-3a86e94f601e"]
}, Open  ]],
Cell[18514, 575, 1120, 32, 53, "Text",ExpressionUUID->"2a9680b1-c62f-447e-adac-6233c1e52e7d"],
Cell[19637, 609, 602, 15, 53, "Text",ExpressionUUID->"3b436687-41d9-4ea4-a622-60fd9f550ccc"],
Cell[20242, 626, 747, 19, 73, "Input",ExpressionUUID->"563dff97-1f75-4b4f-9652-f0d6592adf7b"],
Cell[20992, 647, 727, 20, 53, "Text",ExpressionUUID->"0cc0b86c-0b91-439a-bade-b643345a5cf6"],
Cell[CellGroupData[{
Cell[21744, 671, 277, 4, 30, "Input",ExpressionUUID->"493c1854-3bef-4180-abe8-d7f7c4d4188b"],
Cell[22024, 677, 735, 19, 49, "Output",ExpressionUUID->"777ca600-195f-456a-82d8-9bfad1f04161"]
}, Open  ]],
Cell[22774, 699, 727, 20, 53, "Text",ExpressionUUID->"fbca6586-3ed5-459a-b50d-c2b31dd2a872"],
Cell[CellGroupData[{
Cell[23526, 723, 228, 3, 30, "Input",ExpressionUUID->"f0252a9a-f232-46fe-b998-90847b6a0dab"],
Cell[23757, 728, 969, 26, 49, "Output",ExpressionUUID->"122f1eb1-5ecc-4940-bb58-7967d14e83ec"]
}, Open  ]],
Cell[24741, 757, 726, 20, 53, "Text",ExpressionUUID->"17d45542-73e8-4cef-beae-a9352ac66d6a"],
Cell[CellGroupData[{
Cell[25492, 781, 228, 3, 30, "Input",ExpressionUUID->"85d4b5e5-43a5-47ac-8c4a-29fe9e6266d3"],
Cell[25723, 786, 1085, 30, 49, "Output",ExpressionUUID->"1a9a362e-7f75-4a1c-94e4-b45cade49362"]
}, Open  ]],
Cell[26823, 819, 602, 15, 53, "Text",ExpressionUUID->"c799e14e-0637-4151-a9a3-85c400b1b6fc"],
Cell[27428, 836, 751, 19, 73, "Input",ExpressionUUID->"99e61c54-bdc4-4b33-8b82-8e0d7d880b5f"],
Cell[28182, 857, 776, 21, 53, "Text",ExpressionUUID->"4e573959-b360-49bf-ae4f-b116b07087b9"],
Cell[CellGroupData[{
Cell[28983, 882, 229, 3, 30, "Input",ExpressionUUID->"69c0ffeb-16c5-4012-8473-3e0a99c296e2"],
Cell[29215, 887, 684, 18, 49, "Output",ExpressionUUID->"813dfba7-9933-430f-a971-83751d9a9883"]
}, Open  ]],
Cell[29914, 908, 776, 21, 53, "Text",ExpressionUUID->"316bacd5-131e-49ec-840f-efce06887da8"],
Cell[CellGroupData[{
Cell[30715, 933, 229, 3, 30, "Input",ExpressionUUID->"0443ad6d-08ba-43f4-907c-93d05659c041"],
Cell[30947, 938, 947, 26, 49, "Output",ExpressionUUID->"9fe29c66-ca64-40b1-9ffa-b05d3be39dff"]
}, Open  ]],
Cell[31909, 967, 776, 21, 53, "Text",ExpressionUUID->"ad772f01-1bea-48f3-8dec-84b13a0d0466"],
Cell[CellGroupData[{
Cell[32710, 992, 231, 3, 30, "Input",ExpressionUUID->"7dcfdbe9-6f07-4694-81a6-856af4ab4624"],
Cell[32944, 997, 1060, 30, 49, "Output",ExpressionUUID->"651f75f9-c424-4ff3-aea9-e4d0f3af5698"]
}, Open  ]],
Cell[34019, 1030, 602, 15, 53, "Text",ExpressionUUID->"004e3db8-9908-4586-8da5-a602c0b7d852"],
Cell[34624, 1047, 747, 19, 73, "Input",ExpressionUUID->"cd0892b7-1450-4923-bdc1-e3554c6d9dd6"],
Cell[35374, 1068, 825, 22, 53, "Text",ExpressionUUID->"924c190a-2302-43eb-bf50-2b78c56a6dee"],
Cell[CellGroupData[{
Cell[36224, 1094, 275, 4, 30, "Input",ExpressionUUID->"44d7b32b-c441-471f-b669-ea057a10514d"],
Cell[36502, 1100, 679, 18, 49, "Output",ExpressionUUID->"4726ef6c-3404-4037-9508-2154f87a7ad4"]
}, Open  ]],
Cell[37196, 1121, 825, 22, 53, "Text",ExpressionUUID->"cfb5c831-952b-42b7-8967-a0342e9d1534"],
Cell[CellGroupData[{
Cell[38046, 1147, 226, 3, 30, "Input",ExpressionUUID->"b59b8936-16fe-4ffc-b7c8-b6a023000308"],
Cell[38275, 1152, 922, 25, 49, "Output",ExpressionUUID->"46ed4b13-9f2e-466b-a848-760ffc020dd7"]
}, Open  ]],
Cell[39212, 1180, 825, 22, 53, "Text",ExpressionUUID->"a81f424e-2cd6-410e-801b-22af70969d5c"],
Cell[CellGroupData[{
Cell[40062, 1206, 229, 3, 30, "Input",ExpressionUUID->"d510654b-d5be-4d44-a1ae-295ca4fc1b62"],
Cell[40294, 1211, 1066, 30, 49, "Output",ExpressionUUID->"6275a92b-534e-4ada-a9a8-d9c866fbefa3"]
}, Open  ]],
Cell[41375, 1244, 604, 15, 53, "Text",ExpressionUUID->"ee5259ee-1423-43d8-b1be-821b589c185b"],
Cell[41982, 1261, 747, 19, 73, "Input",ExpressionUUID->"dd445204-39ad-4670-8626-7793d66692a8"],
Cell[42732, 1282, 825, 22, 53, "Text",ExpressionUUID->"f49c0f65-e43d-434f-bde7-f4d42ed63c78"],
Cell[CellGroupData[{
Cell[43582, 1308, 227, 3, 30, "Input",ExpressionUUID->"258d4f7d-ffb0-4148-8501-bf79a67e143d"],
Cell[43812, 1313, 601, 16, 49, "Output",ExpressionUUID->"331abae0-d8b2-4f08-9b9b-bc880dcc03b1"]
}, Open  ]],
Cell[44428, 1332, 873, 22, 53, "Text",ExpressionUUID->"b637f3f4-00e5-4950-b322-1c372142414b"],
Cell[CellGroupData[{
Cell[45326, 1358, 276, 4, 30, "Input",ExpressionUUID->"e70467fa-4c8b-4586-bcce-713880b80faf"],
Cell[45605, 1364, 845, 24, 49, "Output",ExpressionUUID->"8e014a64-a624-4d72-8ddb-637ab2aea0ba"]
}, Open  ]],
Cell[46465, 1391, 875, 22, 53, "Text",ExpressionUUID->"2f8c2afc-cf40-4060-ba50-e636f4bd6f95"],
Cell[CellGroupData[{
Cell[47365, 1417, 325, 5, 30, "Input",ExpressionUUID->"9bd4406f-229d-47d4-bf27-75e0b4b15348"],
Cell[47693, 1424, 957, 28, 49, "Output",ExpressionUUID->"eb42c15f-f88d-48ab-983f-6676d2e399cd"]
}, Open  ]],
Cell[48665, 1455, 684, 15, 53, "Text",ExpressionUUID->"865b81b9-1d36-4088-907c-cc447ed20a71"],
Cell[49352, 1472, 553, 15, 30, "Input",ExpressionUUID->"4020b2d4-f652-4f27-942b-7f9a9ec89fed"],
Cell[CellGroupData[{
Cell[49930, 1491, 450, 11, 30, "Input",ExpressionUUID->"54612606-9590-4977-aec5-5faf0ec74a3c"],
Cell[50383, 1504, 2510, 73, 96, "Output",ExpressionUUID->"b429268a-caa7-453a-bf7d-cabee1c54a9f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52930, 1582, 409, 10, 30, "Input",ExpressionUUID->"9840c230-365c-49c7-ade0-5ba44668859d"],
Cell[53342, 1594, 1058, 29, 50, "Output",ExpressionUUID->"4447c17f-6465-4678-acb2-601d0f4fe88a"]
}, Open  ]],
Cell[54415, 1626, 637, 10, 53, "Text",ExpressionUUID->"02a43df3-3e84-4bec-ad2d-380f6b3e10bc"],
Cell[CellGroupData[{
Cell[55077, 1640, 436, 11, 30, "Input",ExpressionUUID->"8f75e1e1-f7ae-4d64-9bd8-2cdac4bd1854"],
Cell[55516, 1653, 468, 11, 49, "Output",ExpressionUUID->"d7ccabb7-fb4b-405d-b49a-64a2ac432922"]
}, Open  ]],
Cell[55999, 1667, 913, 22, 53, "Text",ExpressionUUID->"99fd2e23-f6a1-4169-a887-2ff12e3ae167"],
Cell[56915, 1691, 675, 15, 53, "Text",ExpressionUUID->"048b4c54-176d-42bc-aa5d-ca2e1d3f209e"],
Cell[57593, 1708, 385, 9, 30, "Input",ExpressionUUID->"6c32f9ab-8549-4ec9-8047-f4f891806e4c"],
Cell[CellGroupData[{
Cell[58003, 1721, 479, 12, 30, "Input",ExpressionUUID->"686839ee-e1ab-4e7a-8bd0-9f8d79e58344"],
Cell[58485, 1735, 385, 8, 49, "Output",ExpressionUUID->"eb1ba5c4-62d4-4f04-9f1a-3f16e009f353"]
}, Open  ]],
Cell[58885, 1746, 727, 15, 53, "Text",ExpressionUUID->"b825c3eb-0c6c-48be-8196-f8f61eba9b84"],
Cell[59615, 1763, 412, 10, 30, "Input",ExpressionUUID->"614cb1d3-ac65-4175-a92c-32eaa730f140"],
Cell[CellGroupData[{
Cell[60052, 1777, 478, 12, 30, "Input",ExpressionUUID->"83c3789b-cf43-4cb7-8cd6-311f7104a258"],
Cell[60533, 1791, 381, 8, 50, "Output",ExpressionUUID->"00c885e3-c899-4839-bc46-be82426731f8"]
}, Open  ]],
Cell[60929, 1802, 720, 15, 53, "Text",ExpressionUUID->"74505a0d-aa10-4d3e-86ab-a1bd071d3e1f"],
Cell[61652, 1819, 404, 9, 30, "Input",ExpressionUUID->"d8de1239-b84a-48a6-9fc2-8cae19f1e19c"],
Cell[CellGroupData[{
Cell[62081, 1832, 531, 13, 30, "Input",ExpressionUUID->"f086fc16-951b-4481-94ad-dd930dac0188"],
Cell[62615, 1847, 310, 4, 34, "Output",ExpressionUUID->"2b58f78b-4cab-458b-9061-151c984660b4"]
}, Open  ]],
Cell[62940, 1854, 725, 15, 53, "Text",ExpressionUUID->"479f1934-8c58-4aba-a5ad-bd197c0f7e4f"],
Cell[63668, 1871, 388, 9, 30, "Input",ExpressionUUID->"78b6ad9c-e09e-4638-97a7-1de8973ee9ac"],
Cell[CellGroupData[{
Cell[64081, 1884, 480, 12, 30, "Input",ExpressionUUID->"19c43925-5c86-424a-bfcc-dc3e7ab7b855"],
Cell[64564, 1898, 576, 15, 50, "Output",ExpressionUUID->"09556cb3-c3e6-4859-9543-b482fd562670"]
}, Open  ]],
Cell[65155, 1916, 735, 15, 53, "Text",ExpressionUUID->"cfc13326-2bcf-4a1a-b9a1-e9b363a070ab"],
Cell[65893, 1933, 360, 8, 30, "Input",ExpressionUUID->"2893ca06-baaa-431a-9b0b-2f60d6cd36de"],
Cell[CellGroupData[{
Cell[66278, 1945, 480, 12, 30, "Input",ExpressionUUID->"b3b96bb9-7565-486e-9869-5370d6d02021"],
Cell[66761, 1959, 695, 18, 50, "Output",ExpressionUUID->"afa3d128-07ab-40ca-8d57-b31ae65be6cc"]
}, Open  ]],
Cell[67471, 1980, 776, 16, 53, "Text",ExpressionUUID->"4b3d9898-e689-4c8c-b25c-97166dfbcd92"],
Cell[68250, 1998, 390, 9, 30, "Input",ExpressionUUID->"b2c1ce38-e8f6-4414-8415-a97860a29764"],
Cell[CellGroupData[{
Cell[68665, 2011, 482, 12, 30, "Input",ExpressionUUID->"b152a936-c916-441b-832a-89f52d8d7999"],
Cell[69150, 2025, 565, 14, 50, "Output",ExpressionUUID->"631e5003-1060-4c8e-9069-3a14a0f211d5"]
}, Open  ]],
Cell[69730, 2042, 772, 16, 53, "Text",ExpressionUUID->"5dac8e94-09a1-4bf3-b621-69aa15b92d38"],
Cell[70505, 2060, 362, 8, 30, "Input",ExpressionUUID->"1b7a2c92-21fe-4a99-8aba-4a5f0cd6616e"],
Cell[CellGroupData[{
Cell[70892, 2072, 477, 12, 30, "Input",ExpressionUUID->"4bba5e2f-65bf-4870-b02f-c5569f2c6d9b"],
Cell[71372, 2086, 590, 15, 50, "Output",ExpressionUUID->"94289231-2160-4ffa-87a0-0b9372693e80"]
}, Open  ]],
Cell[71977, 2104, 774, 16, 53, "Text",ExpressionUUID->"d759bbb0-62b0-47cb-b148-44417fde99b2"],
Cell[72754, 2122, 389, 9, 30, "Input",ExpressionUUID->"5c591503-e2cb-4da0-9ece-7a78ebf766e3"],
Cell[CellGroupData[{
Cell[73168, 2135, 480, 12, 30, "Input",ExpressionUUID->"8166ce6e-5f55-4aa5-80ab-6203c597d1a7"],
Cell[73651, 2149, 383, 8, 50, "Output",ExpressionUUID->"dcef876d-ea98-4f39-81c5-6596a2b53625"]
}, Open  ]],
Cell[74049, 2160, 772, 16, 53, "Text",ExpressionUUID->"8d00d71d-98ae-4094-aa3e-03816d77a5c4"],
Cell[74824, 2178, 362, 8, 30, "Input",ExpressionUUID->"448ace26-d251-4a31-8d1d-922606f40956"],
Cell[75189, 2188, 480, 12, 30, "Input",ExpressionUUID->"7e62932f-ac3f-4bc1-943e-15ec40626233"],
Cell[75672, 2202, 380, 8, 50, "Output",ExpressionUUID->"530643bd-b3a3-4fc6-8023-bdcd7b310ca4"]
}
]
*)

